@@ -197,6 +197,7 @@ analysisOrganizeData <- function(df, analySpec=list(), reports=c(0,1,2,3,4)
 
 # df<-dataCensored; analySpec<-list(); parameterList<-stationMasterList<-layerLukup<-reports<-NA
 # ----- Change history --------------------------------------------
+# 12May2021: JBH: update time periods to 3yr span
 # 24Mar2021: JBH: add a default of gamDiffNumChgYrs as 3 years
 # 03Jun2019: JBH: add report of which models are loaded; mod's to reduce required data elements
 #                 in look up tables: min number of obs for an intervention
@@ -323,8 +324,8 @@ analysisOrganizeData <- function(df, analySpec=list(), reports=c(0,1,2,3,4)
     }
   }
 
-  # specify the average technique to be mean (median option was removed 01May2018)
-  avgTechnique     <- "mean"
+  # specify the average technique to be mean if not specified by user (changed 2021May10)
+  if (!"avgTechnique" %in% names(analySpec)) analySpec$avgTechnique <- "mean"
   
 # 1) Review user supplied specifications.  ####
 
@@ -362,8 +363,8 @@ analysisOrganizeData <- function(df, analySpec=list(), reports=c(0,1,2,3,4)
   # load periods of record to evaluate 
   if (!"gamDiffPeriods"  %in% names(analySpec)) analySpec$gamDiffPeriods   <- list(
     list( periodName = "Full Record",     periodStart = c(NA),        periodEnd = c(NA)),
-    list( periodName = "1999/00-Present", periodStart = c(1999:2000), periodEnd = c(NA)),
-    list( periodName = "2005/06-Present", periodStart = c(2005:2006), periodEnd = c(NA)))
+    list( periodName = "1999/01-Present", periodStart = c(1999:2001), periodEnd = c(NA)),
+    list( periodName = "2011/13-Present", periodStart = c(2011:2013), periodEnd = c(NA)))
 
   if (!"gamDiffSeasons"  %in% names(analySpec)) analySpec$gamDiffSeasons   <- list(
     list ( seasonName = "All",     seasonMonths = c(1:12)),
@@ -431,7 +432,7 @@ analysisOrganizeData <- function(df, analySpec=list(), reports=c(0,1,2,3,4)
 # 3) Aggregate data layers. #####
 
   if ("layer" %in% names(df)) {
-    df<-layerAggregation(df, avgTechnique=avgTechnique, layerAggOption=analySpec$layerAggOption)
+    df<-layerAggregation(df, avgTechnique=analySpec$avgTechnique, layerAggOption=analySpec$layerAggOption)
 
     # create a "layer lookup table" that includes a proper layer name and has a built in preferred
     # order for which order to analyze the layers (mostly to get surface before bottom)
